"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Adaptive = require("./card-elements");
var Enums = require("./enums");
var JsonParser = (function () {
    function JsonParser() {
    }
    JsonParser.prototype.parseBaseAction = function (json, action) {
        action.title = json["title"];
    };
    JsonParser.prototype.parseExternalAction = function (json, action) {
        this.parseBaseAction(json, action);
    };
    JsonParser.prototype.parseActionOpenUrl = function (json, action) {
        this.parseExternalAction(json, action);
        action.url = json["url"];
    };
    JsonParser.prototype.parseActionHttp = function (json, action) {
        this.parseExternalAction(json, action);
        action.url = json["url"];
        action.method = json["method"];
        action.body = json["body"];
        if (json["headers"] != null) {
            var jsonHeaders = json["headers"];
            for (var i = 0; i < jsonHeaders.length; i++) {
                var httpHeader = new Adaptive.HttpHeader();
                httpHeader.name = jsonHeaders[i]["name"];
                httpHeader.value = jsonHeaders[i]["value"];
                action.headers.push(httpHeader);
            }
        }
    };
    JsonParser.prototype.parseActionSubmit = function (json, action) {
        this.parseExternalAction(json, action);
        action.data = json["data"];
    };
    JsonParser.prototype.parseActionShowCard = function (json, action) {
        this.parseBaseAction(json, action);
        var s = [];
        this.parseContainer(json["card"], action.card, "body");
    };
    JsonParser.prototype.createAction = function (json) {
        var result;
        var actionType = json["type"];
        switch (actionType) {
            case Adaptive.OpenUrlAction.TypeName:
                result = new Adaptive.OpenUrlAction();
                this.parseActionOpenUrl(json, result);
                break;
            case Adaptive.HttpAction.TypeName:
                result = new Adaptive.HttpAction();
                this.parseActionHttp(json, result);
                break;
            case Adaptive.SubmitAction.TypeName:
                result = new Adaptive.SubmitAction();
                this.parseActionSubmit(json, result);
                break;
            case Adaptive.ShowCardAction.TypeName:
                result = new Adaptive.ShowCardAction();
                this.parseActionShowCard(json, result);
                break;
            default:
                throw new Error("Unknown action type: " + actionType);
        }
        return result;
    };
    JsonParser.prototype.parseCardElement = function (json, cardElement) {
        cardElement.speak = json["speak"];
        cardElement.horizontalAlignment = Enums.stringToHorizontalAlignment(json["horizontalAlignment"], Enums.HorizontalAlignment.Left);
        cardElement.separation = Enums.stringToSeparation(json["separation"], Adaptive.AdaptiveCard.renderOptions.defaultSeparation);
    };
    JsonParser.prototype.parseTextBlock = function (json, textBlock) {
        this.parseCardElement(json, textBlock);
        textBlock.text = json["text"];
        textBlock.size = Enums.stringToTextSize(json["size"], Enums.TextSize.Normal);
        textBlock.weight = Enums.stringToTextWeight(json["weight"], Enums.TextWeight.Normal);
        textBlock.color = Enums.stringToTextColor(json["color"], null);
        textBlock.isSubtle = json["isSubtle"];
        textBlock.wrap = json["wrap"];
        textBlock.maxLines = json["maxLines"];
    };
    JsonParser.prototype.parseImage = function (json, image) {
        this.parseCardElement(json, image);
        image.url = json["url"];
        image.style = Enums.stringToImageStyle(json["style"], Enums.ImageStyle.Normal);
        image.size = Enums.stringToSize(json["size"], Enums.Size.Medium);
        var selectActionJson = json["selectAction"];
        if (selectActionJson != undefined) {
            image.selectAction = this.createAction(selectActionJson);
        }
    };
    JsonParser.prototype.parseImageSet = function (json, imageSet) {
        this.parseCardElement(json, imageSet);
        imageSet.imageSize = Enums.stringToSize(json["imageSize"], Enums.Size.Medium);
        if (json["images"] != null) {
            var jsonImages = json["images"];
            for (var i = 0; i < jsonImages.length; i++) {
                var image = new Adaptive.Image();
                image.size = imageSet.imageSize;
                image.url = jsonImages[i]["url"];
                imageSet.addImage(image);
            }
        }
    };
    JsonParser.prototype.parseFactSet = function (json, factSet) {
        this.parseCardElement(json, factSet);
        if (json["facts"] != null) {
            var jsonFacts = json["facts"];
            for (var i = 0; i < jsonFacts.length; i++) {
                var fact = new Adaptive.Fact();
                fact.name = jsonFacts[i]["title"];
                fact.value = jsonFacts[i]["value"];
                fact.speak = jsonFacts[i]["speak"];
                factSet.facts.push(fact);
            }
        }
    };
    JsonParser.prototype.parseContainerActions = function (json, container) {
        var jsonActions = json;
        for (var i = 0; i < jsonActions.length; i++) {
            var action = this.createAction(jsonActions[i]);
            if (action != null) {
                container.addAction(action);
            }
        }
    };
    JsonParser.prototype.parseContainer = function (json, container, itemsCollectionPropertyName) {
        this.parseCardElement(json, container);
        container.backgroundImageUrl = json["backgroundImage"];
        container.backgroundColor = json["backgroundColor"];
        container.textColor = Enums.stringToTextColor(json["textColor"], null);
        if (json[itemsCollectionPropertyName] != null) {
            var items = json[itemsCollectionPropertyName];
            for (var i = 0; i < items.length; i++) {
                var element = this.createCardElement(items[i], container);
                if (element != null) {
                    container.addItem(element);
                }
            }
        }
        if (json["actions"] != undefined) {
            this.parseContainerActions(json["actions"], container);
        }
        var selectActionJson = json["selectAction"];
        if (selectActionJson != undefined) {
            container.selectAction = this.createAction(selectActionJson);
        }
    };
    JsonParser.prototype.parseColumn = function (json, column) {
        this.parseContainer(json, column, "items");
        if (json["size"] === "auto") {
            column.weight = 0;
        }
        else if (json["size"] === "stretch") {
            column.weight = -1;
        }
        else {
            column.weight = Number(json["size"]);
        }
    };
    JsonParser.prototype.parseColumnSet = function (json, columnSet) {
        this.parseCardElement(json, columnSet);
        if (json["columns"] != null) {
            var jsonColumns = json["columns"];
            for (var i = 0; i < jsonColumns.length; i++) {
                var column = new Adaptive.Column();
                this.parseColumn(jsonColumns[i], column);
                columnSet.addColumn(column);
            }
        }
    };
    JsonParser.prototype.parseInput = function (json, input) {
        this.parseCardElement(json, input);
        input.id = json["id"];
        input.defaultValue = json["value"];
    };
    JsonParser.prototype.parseInputText = function (json, input) {
        this.parseInput(json, input);
        input.maxLength = json["maxLength"];
        input.isMultiline = json["isMultiline"];
        input.placeholder = json["placeholder"];
    };
    JsonParser.prototype.parseInputNumber = function (json, input) {
        this.parseInput(json, input);
        input.min = json["min"];
        input.max = json["max"];
    };
    JsonParser.prototype.parseInputDate = function (json, input) {
        this.parseInput(json, input);
    };
    JsonParser.prototype.parseInputTime = function (json, input) {
        this.parseInput(json, input);
    };
    JsonParser.prototype.parseInputToggle = function (json, input) {
        this.parseInput(json, input);
        input.title = json["title"];
        input.valueOn = json["valueOn"];
        input.valueOff = json["valueOff"];
    };
    JsonParser.prototype.parseInputChoiceSet = function (json, input) {
        this.parseInput(json, input);
        input.isCompact = !(json["style"] === "expanded");
        input.isMultiSelect = json["isMultiSelect"];
        input.placeholder = json["placeholder"];
        if (json["choices"] != undefined) {
            var choiceArray = json["choices"];
            for (var i = 0; i < choiceArray.length; i++) {
                var choice = new Adaptive.Choice();
                choice.title = choiceArray[i]["title"];
                choice.value = choiceArray[i]["value"];
                input.choices.push(choice);
            }
        }
    };
    JsonParser.prototype.createCardElement = function (json, container) {
        var result;
        var elementType = json["type"];
        switch (elementType) {
            case Adaptive.Container.TypeName:
                result = new Adaptive.Container();
                this.parseContainer(json, result, "items");
                break;
            case Adaptive.TextBlock.TypeName:
                result = new Adaptive.TextBlock();
                this.parseTextBlock(json, result);
                break;
            case Adaptive.Image.TypeName:
                result = new Adaptive.Image();
                this.parseImage(json, result);
                break;
            case Adaptive.ImageSet.TypeName:
                result = new Adaptive.ImageSet();
                this.parseImageSet(json, result);
                break;
            case Adaptive.FactSet.TypeName:
                result = new Adaptive.FactSet();
                this.parseFactSet(json, result);
                break;
            case Adaptive.ColumnSet.TypeName:
                result = new Adaptive.ColumnSet();
                this.parseColumnSet(json, result);
                break;
            case Adaptive.TextInput.TypeName:
                result = new Adaptive.TextInput();
                this.parseInputText(json, result);
                break;
            case Adaptive.NumberInput.TypeName:
                result = new Adaptive.NumberInput();
                this.parseInputNumber(json, result);
                break;
            case Adaptive.DateInput.TypeName:
                result = new Adaptive.DateInput();
                this.parseInputDate(json, result);
                break;
            case Adaptive.TimeInput.TypeName:
                result = new Adaptive.TimeInput();
                this.parseInputTime(json, result);
                break;
            case Adaptive.ToggleInput.TypeName:
                result = new Adaptive.ToggleInput();
                this.parseInputToggle(json, result);
                break;
            case Adaptive.ChoiceSetInput.TypeName:
                result = new Adaptive.ChoiceSetInput();
                this.parseInputChoiceSet(json, result);
                break;
            default:
                throw new Error("Unknown element type: " + elementType);
        }
        return result;
    };
    JsonParser.prototype.parse = function (json) {
        var cardTypeName = json["type"];
        if (cardTypeName != "AdaptiveCard" && Adaptive.AdaptiveCard.onValidationError) {
            Adaptive.AdaptiveCard.onValidationError(Enums.ValidationError.MissingCardType, "Invalid card type. Make sure the card's type property is set to \"AdaptiveCard\".");
        }
        this._card = new Adaptive.AdaptiveCard();
        var minVersion = json["minVersion"];
        var regEx = /(\d+).(\d+)/gi;
        var matches = regEx.exec(minVersion);
        if (matches != null && matches.length == 3) {
            this._card.minVersion.major = parseInt(matches[1]);
            this._card.minVersion.minor = parseInt(matches[2]);
        }
        this._card.fallbackText = json["fallbackText"];
        this.parseContainer(json, this._card.root, "body");
        return this._card;
    };
    return JsonParser;
}());
exports.JsonParser = JsonParser;
//# sourceMappingURL=json-parser.js.map